@@ -1,6 +1,6 @@
 from .EmbThreadPec import get_thread_set
-from .PecReader import read_pec_stitches, read_pec_graphics
-from .ReadHelper import read_int_8, read_int_32le, read_int_16le
+from .PecReader import read_pec_graphics, read_pec_stitches
+from .ReadHelper import read_int_8, read_int_16le, read_int_32le
 
 
 def read(f, out, settings=None):
@@ -16,13 +16,9 @@ def read(f, out, settings=None):
             return  # File terminated before expected end.
         out.add_thread(threadset[color_index % len(threadset)])
     byte_size = pec_graphic_byte_stride * pec_graphic_icon_height
-    read_pec_graphics(f,
-                      out,
-                      byte_size,
-                      pec_graphic_byte_stride,
-                      color_count,
-                      out.threadlist
-                      )
+    read_pec_graphics(
+        f, out, byte_size, pec_graphic_byte_stride, color_count, out.threadlist
+    )
     f.seek(0x2B, 0)
     pec_add = read_int_8(f)  # Size of pre-graphics, post copyright header.
     f.seek(4, 1)  # 0x30, graphics end size.
@@ -36,4 +32,3 @@ def read(f, out, settings=None):
     f.seek(color_count2 + 0x1D, 1)  # 1D toto back
     read_pec_stitches(f, out)
     out.interpolate_duplicate_color_as_stop()
-
