@@ -1,4 +1,4 @@
-from .ReadHelper import read_int_16be, read_int_8, signed8, signed16
+from .ReadHelper import read_int_8, read_int_16be, signed8, signed16
 
 
 def read(f, out, settings=None):
